<?php if ( ! defined( 'FW' ) ) {
	die( 'Forbidden' );
}

/**
 * Main class of the Woffice Auto Friends extension
 *
 */
 
class FW_Extension_Woffice_Auto_Friends extends FW_Extension {

	/**
	 * Setup the extension
	 *
	 * @internal
	 */
	public function _init()
	{
		if (!woffice_bp_is_active('friends')) {
			return;
		}

		add_action('user_register', array($this, 'run'));
		add_action('admin_init',    array($this, 'adminRun'));
	}

	/**
	 * Run the creation from the admin side.
	 */
	public function adminRun()
	{
		$is_enabled = (isset($_GET['extension']) && $_GET['extension'] === 'woffice-auto-friends' && isset($_GET['run']) && $_GET['run'] === 'true');

		if (!$is_enabled) {
			return;
		}

		$count = $this->run();

		?>

		<div class="notice notice-info is-dismissible">
			<p><?php echo sprintf(__('The creation process is now done 🙌 %d relationships were created.'), $count); ?></p>
		</div>

		<?php
	}

	/**
	 * Create the relationships
	 *
	 * @param  int|null   $initiator_id - user ID
	 *
	 * @return int       Number of friendships created 🤝
	 */
	public function run($initiator_id = null)
	{
		$users = get_users(array('fields' => array('id')));

		/**
		 * Filter `woffice_auto_friends_pool`
		 *
		 * Let's you customize which users is included in the auto-friend creation process
		 *
		 * @param array $users
		 */
		$users = apply_filters('woffice_auto_friends_pool', $users);

		$counter = 0;

		if ($initiator_id) {
			return $this->createFriendships($initiator_id, $users);
		}

		foreach ($users as $user) {
			$initiator_id = $user->id;

			$counter = $counter + $this->createFriendships($initiator_id, $users);
		}

		return $counter;
	}

	/**
	 * Create friendship relationships for a given user
	 *
	 * @param  int     $user_id
	 * @param  array   $users
	 *
	 * @return int
	 */
	private function createFriendships($user_id, $users)
	{
		$counter = 0;

		foreach ($users as $user_2) {
			$second_id = $user_2->id;

			if ($user_id === $second_id) {
				continue;
			}

			if (friends_check_friendship($user_id, $second_id) === true) {
				continue;
			}

			$creation = friends_add_friend($user_id, $second_id, true);

			if ($creation === true) {
				friends_update_friend_totals($user_id, $second_id);
				$counter = $counter + 1;
			}
		}

		return $counter;
	}


}